/* -*- mode: c; c-basic-offset: 4; -*- */
/* vi:set cindent ts=8 sts=4 sw=4: */
#ifndef OPTIONS_H
#define OPTIONS_H

#include "curs_main.h" /* struct menu */

#define MSG_FILENAME_EXTENSION_NOT_REGISTERED(filename)\
msg("%s doesn't correlate with the %s variable.", \
	  filename, option_name(OPT_FILENAME_EXTENSIONS));

/* Important! The order of the members in this enumeration *MUST*
   the same as the order of the members of the `option' array in options.c */
enum options {
  OPT_STARTUP_WORKING_DIR,
  OPT_FILENAME_EXTENSIONS,
  OPT_STARTUP_LOAD_DIR,
  OPT_STARTUP_PLAYLIST,
  OPT_DELAY_BETWEEN_SONGS = 4,
  /* the line between the boolean and non-boolean options in the
     options menu is an empty option (its type is `NON_OPTION') */
  OPT_SKIP_COLORS = 6,
  OPT_SHOW_PATH,
  OPT_IGNORE_CASE,
  OPT_CONFIRM_QUIT_CMD
};

void edit_option(int option_index, int *redraw, bool *option_changed);
int get_option_index_by_name(char *option_variable_name);
void initialize_unset_options(void);
bool is_a_boolean_option(enum options option_index);
bool is_a_non_existing_option(enum options option_index);
bool is_a_number_option(enum options option_index);
bool is_a_path_option(enum options option_index);
bool is_a_string_option(enum options option_index);
bool is_boolean_option_true(enum options option_index);
bool is_path_option_set(enum options option_index);
bool is_string_option_set(enum options option_index);
void mark_option_as_initialized(enum options option_index);
int number_of_options(void);
int number_option_value(enum options option_index);
char *option_description_string(enum options option_index);
char *option_name(enum options option_index);
void options_make_menu_entry(char *str, size_t len, int index);
char *path_option_value(enum options option_index);
void reset_all_options(void);
void save_options(char *file);
void set_boolean_option(enum options option_index, bool new_value);
void set_number_option(enum options option_index, int n);
int set_option(enum options option_index, const char *value);
void set_option_to_default_value(enum options option_index);
void set_path_option(enum options option_index, const char *s);
void set_string_option(enum options option_index, const char *s);
char *string_option_value(enum options option_index);
void toggle_boolean_option(enum options option_index);

#endif
